==> aws-java-sdk-emr-1.10.64-sources.jar: com/amazonaws/services/elasticmapreduce/model/transform/InstanceStatusJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.elasticmapreduce.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * InstanceStatusMarshaller
 */
public class InstanceStatusJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(InstanceStatus instanceStatus,
            SdkJsonGenerator jsonGenerator) {
        if (instanceStatus == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (instanceStatus.getState() != null) {
                jsonGenerator.writeFieldName("State").writeValue(
                        instanceStatus.getState());
            }
            if (instanceStatus.getStateChangeReason() != null) {
                jsonGenerator.writeFieldName("StateChangeReason");
                InstanceStateChangeReasonJsonMarshaller.getInstance().marshall(
                        instanceStatus.getStateChangeReason(), jsonGenerator);
            }
            if (instanceStatus.getTimeline() != null) {
                jsonGenerator.writeFieldName("Timeline");
                InstanceTimelineJsonMarshaller.getInstance().marshall(
                        instanceStatus.getTimeline(), jsonGenerator);
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static InstanceStatusJsonMarshaller instance;

    public static InstanceStatusJsonMarshaller getInstance() {
        if (instance == null)
            instance = new InstanceStatusJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-emr-1.10.75.1-sources.jar: com/amazonaws/services/elasticmapreduce/model/transform/InstanceStatusJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.elasticmapreduce.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * InstanceStatusMarshaller
 */
public class InstanceStatusJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(InstanceStatus instanceStatus,
            StructuredJsonGenerator jsonGenerator) {

        if (instanceStatus == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (instanceStatus.getState() != null) {
                jsonGenerator.writeFieldName("State").writeValue(
                        instanceStatus.getState());
            }
            if (instanceStatus.getStateChangeReason() != null) {
                jsonGenerator.writeFieldName("StateChangeReason");
                InstanceStateChangeReasonJsonMarshaller.getInstance().marshall(
                        instanceStatus.getStateChangeReason(), jsonGenerator);
            }
            if (instanceStatus.getTimeline() != null) {
                jsonGenerator.writeFieldName("Timeline");
                InstanceTimelineJsonMarshaller.getInstance().marshall(
                        instanceStatus.getTimeline(), jsonGenerator);
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static InstanceStatusJsonMarshaller instance;

    public static InstanceStatusJsonMarshaller getInstance() {
        if (instance == null)
            instance = new InstanceStatusJsonMarshaller();
        return instance;
    }

}
